const {registerBlockType} = wp.blocks; //Blocks API
const {createElement} = wp.element; //React.createElement
const {__} = wp.i18n; //translation functions
const {InspectorControls} = wp.blockEditor; //Block inspector wrapper
const {serverSideRender} = wp;
const {TextControl,SelectControl} = wp.components; //WordPress form inputs and server-side renderer

registerBlockType( 'efaq-display-block/efaq-widget', {
	title: __('Everest FAQ Manager Lite'), //Block Title
	category: __( 'media' ), //Category
	attributes: {
		heading: {
			default: __('Everest FAQ Manager Lite Title'),
			type: 'string'
		},
		heading_tag : {
			default: 'h2',
			type:'string'
		},
		efaq_id : {
			default: '',
			type: 'string'
		},
	},
	//display the post title
	edit(props){

		const efaqlite = EFAQ_logos_array;

		const attributes = props.attributes;
		const setAttributes = props.setAttributes;

		const headingTags = [
		{ label: 'Heading 1', value: 'h1'},
		{ label: 'Heading 2', value: 'h2'},
		{ label: 'Heading 3', value: 'h3'},
		{ label: 'Heading 4', value: 'h4'},
		{ label: 'Heading 5', value: 'h5'},
		{ label: 'Heading 6', value: 'h6'}
		];

		//Function to update heading level
		function changeHeading(heading){
			setAttributes({heading});
		}

		//Function to update id attribute
		function changeheadingTag(heading_tag){
			setAttributes({heading_tag});
		}

		//Function to update id attributes
		function changeEfaqId(efaq_id){
			setAttributes({efaq_id});
		}

		//Display Block Preview and UI
		return createElement('div', {}, [
			//Preview a block with a PHP render callback
			createElement( serverSideRender, {
				block: 'efaq-display-block/efaq-widget',
				attributes: attributes
			} ),
			//Block Inspector
			createElement( InspectorControls, {}, 
				[
				createElement(TextControl, {
					value: attributes.heading,
					label: __( 'Title'),
					onChange: changeHeading,
				}),
				createElement(SelectControl, {
					value: [attributes.heading_tag],
					label: __( 'Title Tag' ),
					onChange: changeheadingTag,
					options: headingTags,
				}),
				createElement(SelectControl, {
					value: [props.attributes.efaq_id],
					lable: __( 'Everest FAQ Manager' ),
					onChange: changeEfaqId,
					options: efaqlite
				}),
				]
				)
			] )
	},
	save(){
		return null; //Save has to exist. This is all we need
	}
});